import type { MigrateTypes } from '@prisma/internals';
import type { IntrospectionViewDefinition } from './views/handleViewsIO';
export interface RpcRequestResponse {
    id: number;
    jsonrpc: '2.0';
}
export interface RpcSuccessResponse<T> extends RpcRequestResponse {
    result: T;
}
interface RpcErrorResponse<T> extends RpcRequestResponse {
    error: T;
}
export type RpcResponse<T, E> = RpcSuccessResponse<T> | RpcErrorResponse<E>;
export interface RPCPayload extends RpcRequestResponse {
    method: string;
    params: any;
}
interface UserFacingError {
    is_panic: boolean;
    message: string;
    error_code?: string;
    meta?: unknown;
}
export type UserFacingErrorWithMeta = {
    is_panic: boolean;
    message: string;
    error_code: 'P3006';
    meta: {
        migration_name: string;
        inner_error?: {
            is_panic: boolean;
            message: string;
            backtrace: string;
        };
    };
};
export type DriftDiagnostic = {
    diagnostic: 'driftDetected';
    rollback: string;
} | {
    diagnostic: 'migrationFailedToApply';
    error: UserFacingError;
};
export type HistoryDiagnostic = {
    diagnostic: 'databaseIsBehind';
    unappliedMigrationNames: string[];
} | {
    diagnostic: 'migrationsDirectoryIsBehind';
    unpersistedMigrationNames: string[];
} | {
    diagnostic: 'historiesDiverge';
    lastCommonMigrationName: string;
    unpersistedMigrationNames: string[];
    unappliedMigrationNames: string[];
};
export interface MigrationFeedback {
    message: string;
    stepIndex: number;
}
export type DevAction = {
    tag: 'reset';
    reason: string;
} | {
    tag: 'createMigration';
};
export declare namespace EngineArgs {
    /**
     * These RPCs need a sourceConfig, therefore a db connection to function
     */
    export interface ApplyMigrationsInput {
        migrationsDirectoryPath: string;
    }
    export interface CreateMigrationInput {
        migrationsDirectoryPath: string;
        prismaSchema: string;
        draft: boolean;
        migrationName?: string;
    }
    export interface CreateDatabaseInput {
        datasource: MigrateTypes.SchemaContainer | MigrateTypes.UrlContainer | MigrateTypes.PathContainer;
    }
    export interface DropDatabase {
        schema: string;
    }
    type DbExecuteDatasourceTypeSchema = {
        tag: 'schema';
        schema: string;
    };
    type DbExecuteDatasourceTypeUrl = {
        tag: 'url';
        url: string;
    };
    export type DbExecuteDatasourceType = DbExecuteDatasourceTypeSchema | DbExecuteDatasourceTypeUrl;
    export interface DbExecuteInput {
        datasourceType: DbExecuteDatasourceType;
        script: string;
    }
    export type GetDatabaseVersionParams = MigrateTypes.GetDatabaseVersionParams;
    export interface IntrospectParams {
        schema: string;
        force?: Boolean;
        compositeTypeDepth?: number;
        schemas?: string[];
    }
    export interface IntrospectResult {
        datamodel: string;
        warnings: string | null;
        /**
         * Views retrieved from the databases.
         * Supported databases: 'postgresql'.
         *
         * This value is:
         * - `null` if "views" doesn't appear in the schema's preview features
         * - `[]` if the database doesn't have any views
         * - a non-empty array in other cases
         */
        views: IntrospectionViewDefinition[] | null;
    }
    export interface DevDiagnosticInput {
        migrationsDirectoryPath: string;
    }
    export interface DiagnoseMigrationHistoryInput {
        migrationsDirectoryPath: string;
        optInToShadowDatabase: boolean;
    }
    export interface EnsureConnectionValidityInput {
        datasource: MigrateTypes.SchemaContainer | MigrateTypes.UrlContainer | MigrateTypes.PathContainer;
    }
    export interface EvaluateDataLossInput {
        migrationsDirectoryPath: string;
        prismaSchema: string;
    }
    export interface ListMigrationDirectoriesInput {
        migrationsDirectoryPath: string;
    }
    export interface MarkMigrationAppliedInput {
        migrationsDirectoryPath: string;
        migrationName: string;
    }
    export interface MarkMigrationRolledBackInput {
        migrationName: string;
    }
    type MigrateDiffTargetUrl = {
        tag: 'url';
        url: string;
    };
    type MigrateDiffTargetEmpty = {
        tag: 'empty';
    };
    type MigrateDiffTargetSchemaDatamodel = {
        tag: 'schemaDatamodel';
        schema: string;
    };
    type MigrateDiffTargetSchemaDatasource = {
        tag: 'schemaDatasource';
        schema: string;
    };
    type MigrateDiffTargetMigrations = {
        tag: 'migrations';
        path: string;
    };
    export type MigrateDiffTarget = MigrateDiffTargetUrl | MigrateDiffTargetEmpty | MigrateDiffTargetSchemaDatamodel | MigrateDiffTargetSchemaDatasource | MigrateDiffTargetMigrations;
    export interface MigrateDiffInput {
        from: MigrateDiffTarget;
        to: MigrateDiffTarget;
        script: boolean;
        shadowDatabaseUrl?: string;
        exitCode?: boolean;
    }
    export interface SchemaPush {
        schema: string;
        force: boolean;
    }
    export {};
}
export declare namespace EngineResults {
    interface ApplyMigrationsOutput {
        appliedMigrationNames: string[];
    }
    interface CreateDatabaseOutput {
        database_name: string;
    }
    interface CreateMigrationOutput {
        generatedMigrationName: string | null;
    }
    interface DbExecuteOutput {
    }
    interface DevDiagnosticOutput {
        action: DevAction;
    }
    interface DiagnoseMigrationHistoryOutput {
        history: HistoryDiagnostic | null;
        failedMigrationNames: string[];
        editedMigrationNames: string[];
        hasMigrationsTable: boolean;
    }
    interface EvaluateDataLossOutput {
        migrationSteps: number;
        warnings: MigrationFeedback[];
        unexecutableSteps: MigrationFeedback[];
    }
    interface ListMigrationDirectoriesOutput {
        migrations: string[];
    }
    enum MigrateDiffExitCode {
        SUCCESS = 0,
        ERROR = 1,
        SUCCESS_NONEMPTY = 2
    }
    interface MigrateDiffOutput {
        exitCode: MigrateDiffExitCode;
    }
    interface SchemaPush {
        executedSteps: number;
        warnings: string[];
        unexecutable: string[];
    }
}
export interface FileMap {
    [fileName: string]: string;
}
export interface Dictionary<T> {
    [key: string]: T;
}
export {};
